Module client

Traits

GenericClient
Abstraction over multiple types of asynchronous clients. This allows you to use tokio_postgres clients and transactions interchangeably.
Params
This trait allows you to bind parameters to a query using a single struct, rather than passing each bind parameter as a function parameter.

Functions

one
opt
raw